@@ -22,7 +22,6 @@
 #include "libavutil/common.h"
 #include "libavutil/parseutils.h"
 #include "htmlsubtitles.h"
-#include <ctype.h>
 
 static int html_color_parse(void *log_ctx, const char *str)
 {
@@ -52,59 +51,11 @@ static void rstrip_spaces_buf(AVBPrint *buf)
             buf->str[--buf->len] = 0;
 }
 
-/*
- * Fast code for scanning text enclosed in braces. Functionally
- * equivalent to this sscanf call:
- *
- * sscanf(in, "{\\an%*1u}%n", &len) >= 0 && len > 0
- */
-static int scanbraces(const char* in) {
-    if (strncmp(in, "{\\an", 4) != 0) {
-        return 0;
-    }
-    if (!av_isdigit(in[4])) {
-        return 0;
-    }
-    if (in[5] != '}') {
-        return 0;
-    }
-    return 1;
-}
-
-/*
- * Fast code for scanning the rest of a tag. Functionally equivalent to
- * this sscanf call:
- *
- * sscanf(in, "%127[^<>]>%n", buffer, lenp) == 2
- */
-static int scantag(const char* in, char* buffer, int* lenp) {
-    int len;
-
-    for (len = 0; len < 128; len++) {
-        const char c = *in++;
-        switch (c) {
-        case '\0':
-            return 0;
-        case '<':
-            return 0;
-        case '>':
-            buffer[len] = '\0';
-            *lenp = len+1;
-            return 1;
-        default:
-            break;
-        }
-        buffer[len] = c;
-    }
-    return 0;
-}
-
 int ff_htmlmarkup_to_ass(void *log_ctx, AVBPrint *dst, const char *in)
 {
     char *param, buffer[128], tmp[128];
     int len, tag_close, sptr = 1, line_start = 1, an = 0, end = 0;
     SrtStack stack[16];
-    int closing_brace_missing = 0;
 
     stack[0].tag[0] = 0;
     strcpy(stack[0].param[PARAM_SIZE],  "{\\fs}");
@@ -130,31 +81,24 @@ int ff_htmlmarkup_to_ass(void *log_ctx, AVBPrint *dst, const char *in)
             break;
         case '{':    /* skip all {\xxx} substrings except for {\an%d}
                         and all microdvd like styles such as {Y:xxx} */
-            an += scanbraces(in);
-            if (!closing_brace_missing) {
-                if (   (an != 1 && in[1] == '\\')
-                    || (in[1] && strchr("CcFfoPSsYy", in[1]) && in[2] == ':')) {
-                    char *bracep = strchr(in+2, '}');
-                    if (bracep) {
-                        in = bracep;
-                        break;
-                    } else
-                        closing_brace_missing = 1;
-                }
-            }
-
-            av_bprint_chars(dst, *in, 1);
+            len = 0;
+            an += sscanf(in, "{\\an%*1u}%n", &len) >= 0 && len > 0;
+            if ((an != 1 && (len = 0, sscanf(in, "{\\%*[^}]}%n", &len) >= 0 && len > 0)) ||
+                (len = 0, sscanf(in, "{%*1[CcFfoPSsYy]:%*[^}]}%n", &len) >= 0 && len > 0)) {
+                in += len - 1;
+            } else
+                av_bprint_chars(dst, *in, 1);
             break;
         case '<':
             tag_close = in[1] == '/';
             len = 0;
-            if (scantag(in+tag_close+1, buffer, &len) && len > 0) {
+            if (sscanf(in+tag_close+1, "%127[^>]>%n", buffer, &len) >= 1 && len > 0) {
                 const char *tagname = buffer;
                 while (*tagname == ' ')
                     tagname++;
                 if ((param = strchr(tagname, ' ')))
                     *param++ = 0;
-                if ((!tag_close && sptr < FF_ARRAY_ELEMS(stack) && *tagname) ||
+                if ((!tag_close && sptr < FF_ARRAY_ELEMS(stack)) ||
                     ( tag_close && sptr > 0 && !strcmp(stack[sptr-1].tag, tagname))) {
                     int i, j, unknown = 0;
                     in += len + tag_close;
